tocoli.dsl package
==================

Submodules
----------

tocoli.dsl.filter module
------------------------

.. automodule:: tocoli.dsl.filter
    :members:
    :undoc-members:
    :show-inheritance:

tocoli.dsl.join module
----------------------

.. automodule:: tocoli.dsl.join
    :members:
    :undoc-members:
    :show-inheritance:

tocoli.dsl.map module
---------------------

.. automodule:: tocoli.dsl.map
    :members:
    :undoc-members:
    :show-inheritance:

tocoli.dsl.sort module
----------------------

.. automodule:: tocoli.dsl.sort
    :members:
    :undoc-members:
    :show-inheritance:

tocoli.dsl.string module
------------------------

.. automodule:: tocoli.dsl.string
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: tocoli.dsl
    :members:
    :undoc-members:
    :show-inheritance:
